Db

Struct Db 

pub struct Db { /* private fields */ }
Database for persisting game and players state.

Implementations

Source

impl Db

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>

Open a database at the given path.

pub fn open_in_memory() -> Result<Self>

Open an in memory database.

pub async fn join_server( &self, player_id: PeerId, nickname: &str, join_chips: Chips, ) -> Result<Player>

A player join the server.

If the player doesn’t exist it creates one with the given chips, for now if the player exists but has fewer chips than join chips the chips are updated so that the player has enough chips to join.

pub async fn pay_from_player( &self, player_id: PeerId, amount: Chips, ) -> Result<bool>

Pay an amount of chips from a player.

Returns Ok(false) if the player doesn’t have enough chips or an error if the player cannot be found.

pub async fn pay_to_player( &self, player_id: PeerId, amount: Chips, ) -> Result<()>

Pay an amount of chips to a player.

Returns an error if the player has not been found.

pub async fn get_player(&self, player_id: PeerId) -> Result<Player>

Returns the player with the given id.