pub struct Table { /* private fields */ }Expand description
Table state shared by all players who joined the table.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn new(
seats: usize,
sk: Arc<SigningKey>,
db: Db,
shutdown_broadcast_rx: Receiver<()>,
shutdown_complete_tx: Sender<()>,
) -> Self
pub fn new( seats: usize, sk: Arc<SigningKey>, db: Db, shutdown_broadcast_rx: Receiver<()>, shutdown_complete_tx: Sender<()>, ) -> Self
Creates a new table that manages players and game state.
Sourcepub async fn player_can_join(&self) -> bool
pub async fn player_can_join(&self) -> bool
Checks if a player can join the table.
Sourcepub async fn try_join(
&self,
player_id: &PeerId,
nickname: &str,
join_chips: Chips,
table_tx: Sender<TableMessage>,
) -> Result<(), TableJoinError>
pub async fn try_join( &self, player_id: &PeerId, nickname: &str, join_chips: Chips, table_tx: Sender<TableMessage>, ) -> Result<(), TableJoinError>
A player tried to join this table, returns true if the player joined.
Sourcepub async fn message(&self, msg: SignedMessage)
pub async fn message(&self, msg: SignedMessage)
Handle a message from a player.